@@ -649,7 +649,7 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     <name>SettingsForm</name>
     <message>
         <location filename="../ui/settingsform.ui" line="14"/>
-        <location filename="../ui/settingsform.ui" line="671"/>
+        <location filename="../ui/settingsform.ui" line="676"/>
         <source>Settings</source>
         <translation>Настройки</translation>
     </message>
@@ -687,15 +687,15 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
     </message>
     <message>
         <location filename="../ui/settingsform.ui" line="174"/>
-        <location filename="../ui/settingsform.ui" line="488"/>
-        <location filename="../ui/settingsform.ui" line="575"/>
+        <location filename="../ui/settingsform.ui" line="493"/>
+        <location filename="../ui/settingsform.ui" line="580"/>
         <source>Yes</source>
         <translation>Да</translation>
     </message>
     <message>
         <location filename="../ui/settingsform.ui" line="181"/>
-        <location filename="../ui/settingsform.ui" line="495"/>
-        <location filename="../ui/settingsform.ui" line="582"/>
+        <location filename="../ui/settingsform.ui" line="500"/>
+        <location filename="../ui/settingsform.ui" line="587"/>
         <source>No</source>
         <translation>Нет</translation>
     </message>
@@ -735,52 +735,51 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <translation>Тёмный</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="340"/>
         <source>Italiano</source>
-        <translation>Italiano</translation>
+        <translation type="obsolete">Italiano</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="417"/>
+        <location filename="../ui/settingsform.ui" line="422"/>
         <source>Sort album:</source>
         <translation>Сортировка альбомов:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="443"/>
+        <location filename="../ui/settingsform.ui" line="448"/>
         <source>Alphabetical</source>
         <translation>По алфавиту</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="450"/>
+        <location filename="../ui/settingsform.ui" line="455"/>
         <source>By date</source>
         <translation>По дате</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="462"/>
+        <location filename="../ui/settingsform.ui" line="467"/>
         <source>Show track length in library view:</source>
         <translation>Показывать длину трека:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="594"/>
+        <location filename="../ui/settingsform.ui" line="599"/>
         <source>Use hardware keys</source>
         <translation>Аппаратные кнопки</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="615"/>
+        <location filename="../ui/settingsform.ui" line="620"/>
         <source>Zoom keys control:</source>
         <translation>«Качелька» управляет:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="624"/>
+        <location filename="../ui/settingsform.ui" line="629"/>
         <source>Volume</source>
         <translation>Звуком</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="631"/>
+        <location filename="../ui/settingsform.ui" line="636"/>
         <source>Tracks</source>
         <translation>Треками</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="643"/>
+        <location filename="../ui/settingsform.ui" line="648"/>
         <source>Use FMTX</source>
         <translation>Включить FMTX</translation>
     </message>
@@ -815,7 +814,7 @@ MrClon (maemoworld.ru)&lt;br /&gt;hxka (maemoworld.ru)&lt;br /&gt;jerich0 (maemo
         <translation>Язык:</translation>
     </message>
     <message>
-        <location filename="../ui/settingsform.ui" line="555"/>
+        <location filename="../ui/settingsform.ui" line="560"/>
         <source>Pause when headphones unplugged:</source>
         <translation>Пауза при отключении наушников:</translation>
     </message>
